@@ -18,14 +18,15 @@
 
 #include <config-runtime.h>
 #include <config-fish.h>
-#include <QFile>
-#include <QDateTime>
-#include <QRegularExpression>
+
 #include <QCoreApplication>
+#include <QDateTime>
 #include <QDebug>
-#include <QStandardPaths>
-#include <QMimeType>
+#include <QFile>
 #include <QMimeDatabase>
+#include <QMimeType>
+#include <QRegularExpression>
+#include <QStandardPaths>
 
 #include <stdlib.h>
 #include <sys/resource.h>
@@ -53,9 +54,9 @@
 #include <errno.h>
 #endif
 
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
-#include <kremoteencoding.h>
+#include <KMessageBox>
+#include <KLocalizedString>
+#include <KRemoteEncoding>
 
 #include "fishcode.h"
 #include "loggingcategory.h"
@@ -1127,7 +1128,7 @@ void fishProtocol::manageConnection(const QString &l) {
             break;
         case FISH_FISH:
         case FISH_VER:
-            error(ERR_SLAVE_DEFINED,line);
+            error(ERR_WORKER_DEFINED, line);
             shutdownConnection();
             break;
         case FISH_PWD:
